#' boxr: access the Box API
#' 
#' A lightweight, *opinionated*, high-level R interface for the [box.com](https://developer.box.com/docs) API.
#' 
#' This package has a documentation-website (created using [pkgdown](https://pkgdown.r-lib.org/)), containing:
#' 
#' - [README](https://r-box.github.io/boxr/).
#' - [Get-started article](https://r-box.github.io/boxr/articles/boxr.html), 
#'   also accessible from R: `vignette("boxr")`.
#' - [Function reference](https://r-box.github.io/boxr/reference/index.html).
#' 
#' The boxr source-repository is at GitHub: <https://github.com/r-box/boxr>. 
#' 
#' If you find anything you think might be a bug, please report it as a 
#' [GitHub issue](https://github.com/r-box/boxr/issues)!
#' 
#' Happy hacking! :)
#'
#' @name boxr-package
#' @aliases boxr
#' @docType package
#' @keywords package
NULL

## usethis namespace: start
#' @importFrom lifecycle deprecate_soft
## usethis namespace: end
NULL
